Learn R Programming

rport (version 0.0.1)

rport.app.new: Creates an empty folder structure and file templates for an Rport app. If directory `root/name` exists, stops with an error.

Description

Creates an empty folder structure and file templates for an Rport app. If directory `root/name` exists, stops with an error.

Usage

rport.app.new(app.name, root.dir = getwd())

Arguments

name
name of the app
name
of the project