Learn R Programming

rport (version 0.0.1)

rport.db.cache.dir: TODO: for now hardcode this, but we could export this as a setting in config/settings.R. The folder that will contain db cache files.

Description

TODO: for now hardcode this, but we could export this as a setting in config/settings.R. The folder that will contain db cache files.

Usage

rport.db.cache.dir()

Arguments