Learn R Programming

rport (version 0.0.1)

rport.db.cache.file.name: Generate the file name of a cache file given query

Description

Generate the file name of a cache file given query

Usage

rport.db.cache.file.name(query)

Arguments

string
file name of the cache file

Value

string file name of the cache file