Learn R Programming

rport (version 0.0.1)

rport.db.cache.get: Look up for an entry in the .Rportcache file and load the respective file with .Rportcache extension to the global environment.

Description

Look up for an entry in the .Rportcache file and load the respective file with .Rportcache extension to the global environment.

Usage

rport.db.cache.get(query, conn)

Arguments

query
sql query string
conn
string connection name

Value

nil if nothing found or results data.table with the loaded cache