Learn R Programming

rport (version 0.0.1)

rport.db.set.env: This creates an RportDbEnvironment variable in the .GlobalEnv. This is so far the only way to dynamically create objects from a package and should be used with care as it violates the package Namespace.

Description

This creates an RportDbEnvironment variable in the .GlobalEnv. This is so far the only way to dynamically create objects from a package and should be used with care as it violates the package Namespace.

Usage

rport.db.set.env()

Arguments