Learn R Programming

rport (version 0.0.1)

rport.environment.is: Check if the given string is the current runtime environment of Rport. Useful to execute code conditional on runtime environment, e.g. only development or only production.

Description

Check if the given string is the current runtime environment of Rport. Useful to execute code conditional on runtime environment, e.g. only development or only production.

Usage

rport.environment.is(env)

Arguments

env
string the name of the environment to compare

Value

TRUE/FALSE