Learn R Programming

rport (version 0.0.1)

rport.root: The root directory of the Rport app. For now consider this to be the working directory of the R process.

Description

The root directory of the Rport app. For now consider this to be the working directory of the R process.

Usage

rport.root()

Arguments