Learn R Programming

rport (version 0.0.1)

rport.specs.all: Runs the specs of an app found in the app's spec/ folder. You can use this function to run the specs from an interactive R session. This is what is used by the specs/all executable.

Description

Runs the specs of an app found in the app's spec/ folder. You can use this function to run the specs from an interactive R session. This is what is used by the specs/all executable.

Usage

rport.specs.all(root.dir = getwd())

Arguments

root.dir
the path of the app