rport.db.cache.clean: Remove all cache files from tmp/cache folder that have names not found in the
.Rportcache file
Description
Remove all cache files from tmp/cache folder that have names not found in the
.Rportcache file
Usage
rport.db.cache.clean()