rport.db.set.env: This creates an RportDbEnvironment variable in the .GlobalEnv. This is so far
the only way to dynamically create objects from a package and should be used
with care as it violates the package Namespace.
Description
This creates an RportDbEnvironment variable in the
.GlobalEnv. This is so far the only way to dynamically
create objects from a package and should be used with
care as it violates the package Namespace.