rport.environment.is: Check if the given string is the current runtime environment of Rport.
Useful to execute code conditional on runtime environment, e.g. only
development or only production.
Description
Check if the given string is the current runtime environment of Rport.
Useful to execute code conditional on runtime environment, e.g. only
development or only production.