Rdocumentation
powered by
Learn R Programming
rport (version 0.0.1)
rport.is.root.dir: Is the given path a root directory of an Rport app
Description
Is the given path a root directory of an Rport app
Usage
rport.is.root.dir(path)
Arguments
path
character
Value
TRUE/FALSE