Rdocumentation
powered by
Learn R Programming
rport (version 0.0.1)
rport.new: Creates the file sceleton and codebase for a new Rport project. Use it to start a new report, repeatable task, etc.
Description
Creates the file sceleton and codebase for a new Rport project. Use it to start a new report, repeatable task, etc.
Usage
rport.new(name)
Arguments
env
string specifying configuration settings to use.